%define upstream_name    Net-Ping
%define upstream_version 2.75

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

License:    GPL+ or Artistic
Group:      Development/Perl
Summary:    TCP, UDP, or ICMP ping
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Net/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Socket) >= 2.7.0
BuildRequires: perl(Test::More)
BuildRequires: perl(Test::Pod) >= 1.220.0
BuildRequires: perl(Time::HiRes)
BuildArch:  noarch

%description
This module contains methods to test the reachability of remote hosts on a
network. A ping object is first created with optional parameters, a
variable number of hosts may be pinged multiple times and then the
connection is closed.

You may choose one of six different protocols to use for the ping. The
"tcp" protocol is the default. Note that a live remote host may still fail
to be pingable by one or more of these protocols. For example,
www.microsoft.com is generally alive but not "icmp" pingable.

With the "tcp" protocol the ping() method attempts to establish a
connection to the remote host's echo port. If the connection is
successfully established, the remote host is considered reachable. No data
is actually echoed. This protocol does not require any special privileges
but has higher overhead than the "udp" and "icmp" protocols.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
# (tv) those network checks now fail with iurt 0.7.x
rm -f t/200_ping_tcp.t t/400_ping_syn.t t/410_syn_host.t t/420_ping_syn_port.t
%__make test

%install
%make_install

%files
%doc Changes META.json META.yml MYMETA.yml README SIGNATURE TODO
%{_mandir}/man3/*
%perl_vendorlib/*

%changelog
* Sat Jun 28 2025 umeabot <umeabot> 2.750.0-2.mga10
+ Revision: 2215136
- Mageia 10 Mass Rebuild

* Mon Sep 12 2022 tv <tv> 2.750.0-1.mga9
+ Revision: 1887406
- update to 2.75

* Mon Mar 21 2022 umeabot <umeabot> 2.740.0-2.mga9
+ Revision: 1813212
- Mageia 9 Mass Rebuild

* Thu Sep 10 2020 tv <tv> 2.740.0-1.mga8
+ Revision: 1624032
- update to 2.74

* Fri Feb 28 2020 tv <tv> 2.730.0-1.mga8
+ Revision: 1551964
- update to 2.73

* Sat Feb 15 2020 umeabot <umeabot> 2.720.0-2.mga8
+ Revision: 1524271
- Mageia 8 Mass Rebuild

* Fri Mar 29 2019 tv <tv> 2.720.0-1.mga7
+ Revision: 1381144
- update to 2.72

* Wed Oct 17 2018 shlomif <shlomif> 2.710.0-1.mga7
+ Revision: 1321470
- update to 2.71

* Thu Sep 20 2018 umeabot <umeabot> 2.700.0-2.mga7
+ Revision: 1285136
- Mageia 7 Mass Rebuild

* Sun Aug 12 2018 guillomovitch <guillomovitch> 2.700.0-1.mga7
+ Revision: 1251143
- new version 2.70

* Wed Jul 04 2018 shlomif <shlomif> 2.680.0-1.mga7
+ Revision: 1241602
- update to 2.68

* Tue Mar 20 2018 shlomif <shlomif> 2.660.0-1.mga7
+ Revision: 1210674
- update to 2.66

* Thu Mar 08 2018 shlomif <shlomif> 2.650.0-1.mga7
+ Revision: 1207343
- fix build and modernize .spec
- update to 2.65
- update to 2.63

* Wed Oct 04 2017 tv <tv> 2.610.0-3.mga7
+ Revision: 1168810
- disable network tests

* Tue Oct 03 2017 tv <tv> 2.610.0-2.mga7
+ Revision: 1165915
- rebuild with fixed rpm for missing autodeps

* Tue Sep 19 2017 tv <tv> 2.610.0-1.mga7
+ Revision: 1155877
- update to 2.61

* Sun Jun 19 2016 pterjan <pterjan> 2.410.0-6.mga6
+ Revision: 1031273
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 2.410.0-5.mga6
+ Revision: 946726
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.410.0-4.mga5
+ Revision: 749455
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.410.0-3.mga5
+ Revision: 685705
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 2.410.0-2.mga4
+ Revision: 537394
- Mageia 4 Mass Rebuild

* Thu Sep 26 2013 sander85 <sander85> 2.410.0-1.mga4
+ Revision: 486897
- update to 2.41

* Wed Mar 27 2013 jquelin <jquelin> 2.360.0-5.mga3
+ Revision: 405514
- perl 5.16.3 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 2.360.0-4.mga3
+ Revision: 370812
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 20 2011 jquelin <jquelin> 2.360.0-3.mga1
+ Revision: 26719
- mageia rebuild
- imported package perl-Net-Ping

